pub struct UnfinishedPiece {
pub piece: i64,
pub bitmask: Vec<u8>,
}Expand description
A partial piece that was in progress when the torrent was paused/stopped.
Fields
piece: i64Piece index.
bitmask: Vec<u8>Bitmask of which blocks within the piece have been downloaded.