SetBlockResult

Enum SetBlockResult 

pub enum SetBlockResult {
    Ok,
    Unknown,
    HashFailed,
}
Result of setting a block hash in the Merkle tree state.

Variants



Ok

Block hash matches the Merkle tree — all blocks in the piece verified.



Unknown

Piece-layer hash not yet available, or not all sibling blocks present; block hash stored for deferred verification.



HashFailed

Block hash doesn’t match the Merkle tree (bad peer).